#[non_exhaustive]pub enum RateLimitFields {
Draft7,
Draft11,
Disabled,
}Expand description
The Rate Limit Fields revision emitted in responses.
Draft 7 represents RateLimit as a dictionary containing limit, remaining, and reset.
Its RateLimit-Policy field contains the quota and window without a policy identifier.
Draft 11 represents both fields as lists of named items. This crate emits its fixed-window
q/w and r/t parameters; optional quota-unit (qu) and partition-key (pk) parameters
are not emitted.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Draft7
Emit fields compatible with draft 7.
Draft11
Emit fields compatible with draft 11.
Disabled
Do not emit RateLimit or RateLimit-Policy fields.
Rate-limited responses still include Retry-After.