pub struct Usage {
pub used: u64,
pub reset_after: Duration,
}Expand description
The usage and reset duration returned by a store.
Fields
used: u64Total charged requests in the current window, including this increment.
reset_after: DurationTime remaining until the current window resets.